---
title: "Introduction"
type: Chapter
slug: true
front: false
---

>> The real long-term future of computing consists of figuring out how to make the best possible use we can out of the literal millions of devices which already exist.

<cite>(Solderpunk, 2020, Cited in de Valk, 2022)
<span style="display: none;">[@devalkSalvagedComputing2024]</span></cite>

Beware! If you’ve picked up this publication expecting to learn how to make a flawless, DAW-less, in tune and always working polysynth, think again. However, if you, like me, are interested in making screamy, dreamy, sound devices using components you can find *in the wild*, you've come to the right place.

When I first read about salvage computing, I got very excited. Being part of the DIY Sound community, as a sound practitioner and hardware hacker, I’ve developed a growing discomfort with some aspects of the practice. Within the DIY Sound community, DIWO workshops are a common way of sharing knowledge [@richardsDIYMakerCommunities2017], covering a wide range of topics, from the construction to bending and hacking and live coding. Over the past few years, I’ve hosted workshops around circuit bending[^circuit-bending] and LOFI sound devices in and around Rotterdam. These workshops are meant as an accessible way to get people tinkering with electronics, through something infinitely playful: making instruments[^playful].

[^circuit-bending]: the practice around hacking discarded toys to find sonic potential through creating shorts, or sometimes literally bending the circuit.

[^playful]: Making instruments is an engaging way to learn about and work with the flow of electricity.

In an ecosystem where a printer is only printing with a costly subscription [^printer-subscription], disruptive products become obsolete within a year[^AI-pin], fixing your own flat tires is outsourced [^swapfiets] and some smartphones literally have to be frozen to be able to replace the battery [^frozen], it’s clear we’re no longer in charge of our own devices. Warranty-void stickers and lengthy terms and conditions scare us into compliance.

First time soldering workshops can be very empowering in taking back this autonomy by making (or breaking) a circuit together[^exchange]. They are a shared attempt to uncover some of the black boxes in our own products [@hertzZombieMediaCircuit2012]. However, the toys and materials used in the workshops are single-use [^single-use] and, with ease, thrown out afterward. The carelessness notion creeps in that waste has no value, and is easily replaceable, and broke my heart a bit, one workshop at a time.

[^exchange]: Especially during a [workshop in collaboration with the kunsthal](https://www.kunsthal.nl/nl/plan-je-bezoek/activiteiten/friday-night-live-operator/), where it was the first time making a circuit for many attendees. It was great to see how people without much electronics experience figured out circuit making and playing, together.


[^printer-subscription]: HP’s “all-inclusive” printers can only be used with an active subscription [@hachmanNightmareRealHP2024].

[^AI-pin]: Humane Inc. Ai Pin closed their servers within one year after releasing their *A.I. Pin*. Now, you can only ask this piece of hardware how many batteries it has left [@chokkattuWhatYourDefunct2025].

[^swapfiets]: Swapfiets promote their bike subscriptions as “We give you a bike that you never have to repair”.

[^frozen]: The Nothing Phone scored a 1/10 in iFixit's repairability score [@havardEssentialPhoneTeardown2017].

[^single-use]: and often require much preparation in terms of collecting, transporting, repairing, testing, and cleaning.

This is where the field guide comes into play: Can we shift the practice of playful tinkering to acknowledge, rather than ignore, the waste streams they are part of? Limiting ourselves to only use salvaged components and discovering; is it possible to live off (create with) electronic components salvaged in the wild? And what would such a practice entail?

Because salvage is not just about reusing materials; but about confronting the systems that create the waste in the first place. Not only the obsolete media but also the by-product of the entire production lifecycle of an electronic product; From the mining of minerals that make up the hardware to the inevitable disposal site [@gabrysSalvage2012]. Since the rate at which waste is collected and recycled isn't growing at the same pace as our collective buying and production, the landfills will continue to grow. Parikka even goes as far to say as that recycling is ultimately "waste-trade", where our abandoned devices are shipped across the ocean [@parikkaDustMatter2012].

## Beyond the kit
The preference for buying new is noticeable in the DIY synth community as well. When publishing a project, it's common to share a pre-filled webshop cart along with the schematics or even sell it as a pre-compiled kit[^KIT]. To me, this goes against the ethos of DIY that resonates with me the most: making do with what you have, with a focus on doing, and not the outcome [@hertzArtDIYElectronics2023]. Instead, a whole market is created for Lego-like kits. These kits gloss over the challenges and difficulties of creating sound devices, preventing the development of much-needed problem-solving skills, and not actually discovering anything new [@CooperativeExperimentalismSharing].

[^KIT]: ![Kit from Bastl Instruments](/chapters/bastl_kit.webp)

Instead, what you will learn to build using this guide is a starting point. Small electronic circuits that produce sound on their own, but can also be duplicated, manipulated, and modulated [^disclaimer], while diving into the questions around the practice of salvaging. The guide is tested, tinkered, and tweaked during (un)repair cafe evenings at the Klankschool[^klankschool]. In these hangouts we modify, hack and repair devices together.

[^klankschool]: Klankschool is a loose-knit group of sonic practitioners based in Rotterdam who share a common interest in performances, sound art, improvisation and noise. Everyone involved is a teacher, student, musician, janitor and more. Check the [calendar](https://calendar.klank.school/) for the next event!

[^disclaimer]: *I am by no means an expert in electronics. This guide represents my personal understanding of electronics, which, in no doubt, contains incorrect assumptions or oversimplifications.*

The guide is split up into the different stages of salvaging:

#### 1. Gathering hardware
*We trace where to find discarded electronics and how industry practices shape what ends up in the trash.*

#### 2. Dismantling devices
*Opening up devices to uncover design strategies that prevent access*

#### 3. Components to salvage
*Identifying and extracting useful components—motors, sensors, chips, while diving deeper in their material.*

#### 4. Recipes for making
*Methods for building sound devices.*

#### 5. Taking inventory
*Time to clean the workbench and reflect*

Happy scavenging!

![A sound device](/chapters/transistorOSC_white.webp){.img--fullpage}
