---
title: "Components"
type: Chapter
slug: true
nested: "components"
front: true
---

Once you’ve broken your device down into its individual puzzle pieces, we can zoom in on them more closely. Is there anything that immediately sparks your interest? Did you already uncover unexpected materials? Chances are you uncovered one or more Printed Circuit Boards (PCBs), and—very generally speaking—some kind of input and output components, all connected by several types of wire[^wires]. For example, inside a digital picture frame I found a power input, a battery, a screen, speakers, a two-sided PCB, and an antenna.

PCBs are populated with either “through hole" (THT) or "surface mount" (SMD) components. SMD components are very small and soldered directly onto the board's surface. Their size makes labels hard to read, and they’re designed for automated assembly, making them impractical for salvage[^tried]. That’s why I rarely salvage from computer-type devices. These usually contain nothing but SMD components and lack interesting interactions or mechanical parts.

[^tried]: The biggest issue is the size of the legs, which are impossible to solder without making your own PCB's. I’ve made prototypes with cutting the entire PCB, using conductive ink, copper tape and charcoal pens. None of the strategies worked well

[^wires]: Great for reuse as well!

## Desoldering
Desoldering components is generally more difficult than soldering and requires patience and practice. Ironically, desoldering guns are much more expensive than soldering irons, so here’s how I do it, without one.

In a well-ventilated[^well-ventilated] room, heat up the blob of solder that connects the component to the PCB using a soldering iron. After a couple of seconds, you’ll notice the solder becomes liquid[^liquid].

Then, using tweezers or a plier, I carefully pull the leg out from the backside of the board, and then do the same for the other legs. This process can take somewhere between 10 seconds and 10 minutes and can be both frustrating and meditative.

[^well-ventilated]: whilst modern devices cannot contain lead anymore, older solder will. Do not lick the PCB, clean your hands after and open a window.

[^liquid]: How fast this happens depends on the temperature of the soldering iron and the melting point of the solder that is on the board. If it won’t melt, adding a bit of your own solder helps.

## Common components
In the next few pages, I’ll briefly address some of the more common components. If you want to know more about what each component specifically does, I recommend Getting started in electronics [@mimsGettingStartedElectronics1983].

Many components, like transistors and chips, have datasheets available online. You can usually find them by entering the part number, often printed directly on the component[^unless], into a search engine. While datasheets can be overwhelming and full of technical jargon, they typically show a pinout, explaining what each leg does, and a description of the component's behavior.

In the next chapter, we’ll get into making with the salvaged components. The recipes need some specific components, which are highlighted below. It's always wise to have some extra! Components might break, speaking from experience, having to stop because you've run out of working components, is very discouraging.

[^unless]: Since the manufacturer didn’t think you ever needed to know which oddly specific chip you’re looking at, they sometimes deliberately scratched it off.

::: {.table-wide}

## Overview of common components

| **Name**                           | **Category**             | **Description**                                                  | **Found in**                                  | **Symbol**                                               |
|------------------------------------|--------------------------|------------------------------------------------------------------|-----------------------------------------------|----------------------------------------------------------|
| **555 Timer**                      | Chip                    | A small chip that generates pulses                               | Timers, LED dimmers                           |                                                          |
| **<mark>Capacitor</mark>**                      | Capacitor                | Store a voltage                                                  | Everywhere!                                   | ![](./assets/schematics/Capacitor-IEC-Polarized.svg)     |
| **<mark>Coil</mark>**                           | Passive        | These funky components can create sounds on their own            | Transformers, relays, wireless charging       | ![](./assets/schematics/Inductor-COM-Air.svg)            |
| **Crystal Oscillator**             | Passive                  | Generates a frequency that is often used as a clock              | Devices that have processors                  |                                                          |
| **Diode**                          | Passive                    | Forces current to flow in one direction                          | Everywhere!                                   | ![](./assets/schematics/Diode-COM-Standard.svg)          |
| **Displays**                       | Output                  | Display information                                              | Monitors, calculators, embedded systems       |                                                     |
| **<mark>LED</mark>**     | Output                    | Emit a small light                                               | Everywhere!                                   | ![](./assets/schematics/Diode-COM-LED.svg)               |
| **Logic chips**                    | Chip                    | Create logic and switches                                        | Computers, microcontrollers, control circuits |                                                          |
| **MOSFET**                         | Chip                    | Not sure yet                                                     | Power supplies, motor control                 |                                                          |
| **<mark>Magnet</mark>**                         | Misc                     | Electromagnetic applications, motors                             | Speakers, hard drives                         |                                                     |
| **Microcontroller**                | Chip                    | Programmable chip, for example the ATmega328                     | Embedded systems, Arduino, automation         | ![](./assets/schematics/Capacitor-IEC-Polarized.svg)     |
| **Microphone**                     | Input                    | Record sound                                                     | Phones, vapes                                 | ![](./assets/schematics/Audio-IEEE-Microphone.svg)       |
| **<mark>Motor</mark>**                          | Output | Spins when a power is applied                                    | Printers, blenders, vacuums                   |                       |
| **NPN Transistor**                 | Transistor               | Amplification/switching                                          | Everywhere!                                   | ![](./assets/schematics/Transistor-COM-BJT-NPN.svg)      |
| **Op-Amp** | Chip                    | Amplifying signals                                               | Audio circuits, sensors, control systems      | ![](./assets/schematics/IC-COM-OpAmp.svg)                |
| **<mark>PNP Transistor</mark>**                 | Transistor               | Amplification/switching                                          | Everywhere!                                   | ![](./assets/schematics/Transistor-COM-BJT-PNP.svg)      |
| **Piezo disc**                     | Ouput/Input              | Records or creates vibrations                                    | Buzzers, sensors                              |                                                          |
| **<mark>Potentiometer</mark>**                  | Resistor                 | Limiting voltage through a knob                                  | Volume knobs, light dimmers                   | ![](./assets/schematics/Resistor-IEEE-Potentiometer.svg) |
| **Relay**                          | Switch        | Switches power                                                   | Household appliances                          | ![](./assets/schematics/Relay-COM-COM-SPDT.svg)          |
| **<mark>Resistor</mark>**                       | Resistor                 | Limiting voltage                                                 | Everywhere!                                   | ![](./assets/schematics/Resistor-IEEE-Standard.svg)      |
| **Speaker**                        | Ouput                    | Outputs sound                                                    | Toys, (portable) radios                       | ![](./assets/schematics/Audio-COM-Loudspeaker.svg)       |
| **Switches & buttons**             | Input                    | Interact with the device                                         | Light switches, keyboards                     | ![](./assets/schematics/Switch-COM-SPST.svg)             |
| **Thermistor**                     | Resistor                 | Limiting voltage dependent on temperature                        | Not sure yet                                  | ![](./assets/schematics/Resistor-IEEE-Thermistor.svg)    |
| **Trimpots**                       | Resistor                 | Limit voltage through a small knob adjustable with a screwdriver | Audio circuits, calibration devices           | ![](./assets/schematics/Resistor-IEEE-Trimmer.svg)       |
| **Voltage regulators**             | Chip        | Not sure yet                                                     | Power supplies, embedded systems              |                                                          |                                                     |                          |
:::
