---
title: "Recipes for reuse"
type: Chapter
slug: true
front: true
nested: "recipes"
---

Hopefully, you’ve salvaged a variety of components by now, and we can start building sound with them. In this chapter you'll find a bunch of recipes; the starting points for sound devices. These modular recipes can be used standalone or connected together into a bigger system. This modularity makes problem-solving slightly easier[^easier], and you can pick and choose your modules based on your salvaged inventory.

[^easier]: Still a headache! But now you only have to triple check a handful of components, instead of 120.

Every recipe contains a paper circuit[^paper-circuit-ciat] to print. These circuits are the blueprint of your device, between a schematic and an industrial PCB. The biggest advantage of using paper, apart from being able to solder the connections of your components right on top of the circuit, is that it is flexible. You can take notes, draw lines, and adjust the schematic as you go.

[^paper-circuit-ciat]: A method introduced by synthesizer builder Ciat Lonbarde, who used paper circuits to distribute his circuits and ideas for free [@blasserStoresMall2015].

### Assembling the circuit

1. Cut out the circuit and fold it in half, creating a two-sided print [^print].
2. Gather the components listed in the "Bill of Materials" (BOM).
3. Populate the first components by pinning the legs through the paper in their designated areas. Keep an eye on the orientation[^orientation]. Start small (resistors) then move to larger parts.
4. Create the connections according to the circuit by soldering the legs together using (copper) wire.
5. Repeat until all components are in place!
6. Test & triple-check all connections [^triple-check].

[^print]: printing on thicker paper is advised

[^orientation]: Some capacitors, LED's and other components all have a specific polarity/orientation.

[^triple-check]: With salvaged components you'll have a limited supply. Test to prevent component loss.

There is no need to understand every single component on each recipe [^no-need] but try to follow the connections on the circuit. Which road is the audio signal taking? This will help you a lot with troubleshooting.

[^no-need]: Rule #17 from Handmade Electronic Music states, "If it sounds good and doesn’t smoke, don’t worry if you don’t understand it." [@collinsHandmadeElectronicMusic2009].

!Safety notes!

- **Audio can be surprisingly loud**. Use small speakers (never headphones! [^headphones]) you wouldn’t miss if they break and keep your hand on the volume dial when plugging in your sound device for the first time.
- **Use batteries**. Plugging into a wall (120V) can be incredibly dangerous. Always unplug the power from the circuit when making changes, to prevent shorts.
- **Watch that smell**. “Magic smoke” has a certain smell. Unplug immediately when something smells/smokes!
- **Two know more than one**. If you're not sure, invite a friend and I'm sure you'll figure it out together.

[^headphones]: Your hearing is precious, and accidentally blasting an overpowered sinewave Through your ears can cause permanent damage.

### Finding recipes
The DIY synth community is not shy in sharing their schematics. There are fantastic resources online, such as the Experimentalists Anonymous DIY Archives the wiki, Music from Outer Space and Handmade Electronic Music [@collinsHandmadeElectronicMusic2009]. However, finding resources using salvaged components can be tricky, as our requirements are a bit different. Most schematics either contain 20+ components or require (specific) chips, which have proven to be difficult to find. This limitation has been interesting, as it forces me to experiment with smaller schematics. Turning the oscillators into self-modulating instruments, by attaching them together using alligator clips, actually helped me to learn more about electronics & sound than any pre-made kit could ever do.

![Combine multiple recipes to create a self-modulating glitch device!](/chapters/croc.webp){.img--fullpage}

 
